@@ -182,12 +182,13 @@ class mainWindow(mainWindowBA):
 
 
     def address_book_action_toggle(self):
-        if self.address_book.get(self.current_projectVO.getProjectName()) and \
-           self.settings['smtp_server']:
+        if self.current_projectVO and \
+               self.address_book.get(self.current_projectVO.getProjectName()) and \
+               self.settings['smtp_server']:
             enable = True
         else:
             enable = False
-
+        
         self.emailAnnouncementAction.setEnabled(enable)        
         
 
@@ -216,11 +217,22 @@ class mainWindow(mainWindowBA):
             #    self.packageTabWidget.setFocus()
         
 
+    def hasFullAccess(self, packages):
+        # if any package has full access return true, false otherwise
+        if not packages: return False
+        
+        for pkg in packages:
+            print pkg.getFullAccess()
+            if pkg.getFullAccess() == "True": return True
+        return False
+
+
     def populatePackages(self, group_id):
         self.packagesListView.clear()
         packages = self.projects_dict.get(group_id)
         debug("packages: %s", packages)
         self.__initialize_package_fields()
+        full_access = False
         if packages:
             for package in packages:
                 pkg_item = QListViewItem(self.packagesListView)
@@ -228,9 +240,11 @@ class mainWindow(mainWindowBA):
                 pkg_item.setText(COL_PKG_ID, package.getPackageId())
                 pkg_item.setText(COL_PKG_STATUS, package.getPackageStatus())
                 pkg_item.setText(COL_PKG_FULLACCESS, package.getFullAccess())
+                if package.getFullAccess() == "True": full_access = True
             if len(packages) == 1:
                 self.packagesListView.setSelected(pkg_item, True)
                 #self.packageSelected(pkg_item)
+        self.hideTabWidgets(full_access)
 
 
     def __initialize_package_fields(self):
@@ -263,8 +277,11 @@ class mainWindow(mainWindowBA):
         self.current_project_item = item
         self.current_projectVO = self.__getProjectFromItem(item)
         group_id = self.current_projectVO.getGroupId()
+        
         debug("projectSelected: %s", group_id)
+        
         self.populatePackages(group_id)
+
         self.submitNewsAction.setEnabled(1)
 
         self.freshmeat_release_action_toggle()
@@ -341,6 +358,17 @@ class mainWindow(mainWindowBA):
                          str(item.text(COL_PROJ_GROUP)))
 
 
+    def hideTabWidgets(self, full_access):
+        if not full_access:
+            self.updatePackageLineEdit.setReadOnly(True)
+            self.newPackageLineEdit.hide()
+            self.newPackageTextLabel.hide()
+            self.AddPackagePushButton.hide()
+            self.updatePackagePushButton.hide()
+        else:
+            self.newPackageLineEdit.show()
+            self.newPackageTextLabel.show()
+
     def packageSelected(self, item):       
         self.current_package_item = item
         pkg = self.__getPackageFromItem(item)
@@ -356,9 +384,17 @@ class mainWindow(mainWindowBA):
 
         if pkg.getFullAccess() == "True":
             self.updatePackageLineEdit.setReadOnly(False)
+            self.newPackageLineEdit.show()
+            self.newPackageTextLabel.show()
+            self.AddPackagePushButton.show()
+            self.updatePackagePushButton.show()
         else:
             self.updatePackageLineEdit.setReadOnly(True)
-            
+            self.newPackageLineEdit.hide()
+            self.newPackageTextLabel.hide()
+            self.AddPackagePushButton.hide()
+            self.updatePackagePushButton.hide()
+
         self.packageIdLineEdit.setText(pkg.getPackageId())
 
         #enable
