@@ -61,6 +61,7 @@ class ReleaseWizard(ReleaseWizardBA):
         self.projectVO = projectVO
         self.packageVO = packageVO
         self.create = create
+        self.reguessFrame.hide()
 
         if not self.create:
             self.releaseNotifyCheckBox.setChecked(False)
@@ -402,6 +403,26 @@ class ReleaseWizard(ReleaseWizardBA):
             cpuCombo.setCurrentItem(name or 0) 
         if self.__validateFiles(rownum):
             self.setNextEnabled(self.page(WIZARD_PAGE_FILE_SELECTION), True)
+
+
+    def reguessFileAttributes(self):
+        rownum = self.releaseFilesTable.numRows()
+        for i in range(rownum):
+            filename = str(self.releaseFilesTable.text(i, COL_BASENAME))
+            cpu = self.__guessProcessorType(filename)
+            filetype = self.__guessFileType(filename)
+           
+            cpuCombo = self.releaseFilesTable.item(i, COL_CPU)
+            currcpu = str(cpuCombo.currentText())
+            if currcpu != cpu:
+                cpuCombo.setCurrentItem(cpu)
+            
+            fileTypeCombo = self.releaseFilesTable.item(i, COL_FILE_TYPE)
+            currfiletype = str(fileTypeCombo.currentText())
+            if currfiletype != filetype:
+                fileTypeCombo.setCurrentItem(filetype or 0)
+
+            
             
             
     def addFiles(self):
@@ -415,6 +436,7 @@ class ReleaseWizard(ReleaseWizardBA):
 
         if files:
             self.processorComboBox.setEnabled(True)
+            self.reguessFrame.show()
        
         for f in files:
             fstr = str(f)
@@ -523,6 +545,7 @@ class ReleaseWizard(ReleaseWizardBA):
 
         if self.releaseFilesTable.numRows() == 0:
             self.processorComboBox.setEnabled(False)
+            self.reguessFrame.hide()
             if self.create:
                 self.setNextEnabled(self.page(WIZARD_PAGE_FILE_SELECTION), False)
 
@@ -663,6 +686,7 @@ class ReleaseWizard(ReleaseWizardBA):
         
         rownum = 0
         fileVOs = []
+
         for f in files:
             fileid = f[0]
             filename = f[1]
@@ -682,6 +706,7 @@ class ReleaseWizard(ReleaseWizardBA):
                            "",
                            fileid)
 
+        if files: self.reguessFrame.show()
 
         debug("selected_files: %s", self.selected_files)
         releaseVO.setFiles(fileVOs)
@@ -961,15 +986,20 @@ class ReleaseWizard(ReleaseWizardBA):
         self.fileAttribTextLabel.setEnabled(True)
         warned_filenames = []
         fileVOs = self.releaseVO.getFiles()
+        
+        #for f in fileVOs:
+        #    debug("fileVO: %s", f)
+            
         if type(data_tuple) is TupleType:
             # create
+            debug("creating lookup_dict: %s - %s - %s", data_tuple[0], data_tuple[1], data_tuple[2])
             lookup_dict = data_tuple[0]
             warned_filenames = data_tuple[1]
             ok = data_tuple[2]
             if warned_filenames:
                 for vo in fileVOs:
                     if vo.getFilename() in warned_filenames:
-                        fileVOs.remove(vo)                    
+                        fileVOs.remove(vo)
         else:
             # edit
             ok = data_tuple
