@@ -21,6 +21,7 @@ from constants import SF_RESPONSE_CHUNK_SIZE
 
 debug = logging.getLogger("sfcomm").debug
 error = logging.getLogger("sfcomm").error
+exception = logging.getLogger("sfcomm").exception
 
 # disable debug level logging in the cookielib module
 logging.getLogger("cookielib").setLevel(logging.WARN)
@@ -62,7 +63,8 @@ class SFComm:
                   post_encoded=None,
                   queue=progressMessageQueue,
                   addl_headers=None,
-                  ok_status=None):
+                  ok_status=None,
+                  dbg=None):
         #
         # parameters:
         # url: url to retrieve
@@ -99,6 +101,7 @@ class SFComm:
                 opener.addheaders = addl_headers
                 
             r = opener.open(url, post_encoded)
+#            debug("r methods: %s", dir(r))
 #            cj.save(self.cookie_file, True)
             if not ok_status: 
                 # fetch entire response
@@ -110,10 +113,11 @@ class SFComm:
                     chunk = r.read(SF_RESPONSE_CHUNK_SIZE)
                     
                     if not chunk:
+                        debug("read chunk returned no data? %s", type(chunk))
                         ok = False 
                         break
                     data = "%s%s" % (data, chunk)
-                    debug("fetched: %d bytes", len(data))
+                    if dbg: debug("fetched: %d bytes", len(data))
 
                     if data.find(ok_status) != -1:
                         break
@@ -123,10 +127,12 @@ class SFComm:
                     debug("did not find '%s' in response", ok_status)
 
             r.close()
-            debug("Done")
+            if dbg: debug("Done")
             #debug("length: %ld  -  url: %s", len(data), url)
         except Exception, e:
             print e
+
+        if dbg: debug("DATA: %s", data)
         return data, ok
 
 
@@ -403,13 +409,14 @@ class SFComm:
             filename = fileVO.getFilename()
             enc += "&file_list%s=%s" % (quote_plus("[]"), quote_plus(filename))
             
-        data, ok = self.fetch_url(url, enc, ok_status="File(s) Added")
+        #data, ok = self.fetch_url(url, enc, ok_status="File(s) Added", dbg=True)
+        data, ok = self.fetch_url(url, enc)
 
         warnings = GET_FILE_WARNINGS.findall(data)
         debug("step2 warnings: %s", str(warnings))
 
-#        if data.find("File(s) Added") != -1: ok = True
-#        else:
+        if data.find("File(s) Added") != -1: ok = True
+
         if not ok:
             error("Error selecting %s for inclusion", filename)
             #debug("dumping data: %s", data)  # remove me...
@@ -439,16 +446,14 @@ class SFComm:
             form['processor_id'] = fileVO.getProcessorId()
             form['type_id'] = fileVO.getFileTypeId()
             try:
+                #debug("filename: %s", fileVO.getFilename() )
+                #debug("dict: %s", str(lookup_dict))
+                
                 form['file_id'] = lookup_dict[fileVO.getFilename()]
                 ok &= self.fetch_url(url, urlencode(form), ok_status="File Updated")[1]
-#                if data.find("File Updated") != -1: ok &= True
-#                else: ok &= False
             except Exception, e:
-                error(e)
+                exception(e)
                 ok &= False
-
-            #print data
-            #print "\n\n\n\n\n---------------------------------\n"
         return ok
     
 
